@@ -2,11 +2,13 @@
 #
 # Author: Yipeng Sun <syp at umd dot edu>
 # License: BSD 2-clause
-# Last Change: Thu Sep 10, 2020 at 03:48 AM +0800
+# Last Change: Tue Sep 22, 2020 at 02:33 AM +0800
 
 import re
 
+from pyBabyMaker.base import TermColor as TC
 from pyBabyMaker.base import UniqueList, BaseMaker, Variable
+from pyBabyMaker.base import update_config
 from pyBabyMaker.boolean.utils import find_all_vars
 from pyBabyMaker.engine.core import template_transformer, template_evaluator
 
@@ -15,7 +17,7 @@ from pyBabyMaker.engine.core import template_transformer, template_evaluator
 # Configuration parser #
 ########################
 
-class BabyConfigParser(object):
+class BabyConfigParser:
     """
     Basic parser for YAML C++ code instruction.
     """
@@ -45,23 +47,24 @@ class BabyConfigParser(object):
         for output_tree, config in self.parsed_config['output'].items():
             input_tree = config['input']
             dumped_tree = self.dumped_ntuple[input_tree]
-            print('=== Handling output tree {} ==='.format(output_tree))
+            print('{}=== Handling output tree {} ==={}'.format(
+                TC.BOLD+TC.BLUE, output_tree, TC.END))
 
             # Merge raw tree-specific directive with the global one.
             merge = config['inherit'] if 'inherit' in config else True
-            self.update_config(config, self.parsed_config, merge=merge)
+            update_config(config, self.parsed_config, merge=merge)
 
-            # Empty parsed tree-specific directive.
             subdirective = self.gen_subdirective(input_tree)
+            update_config(subdirective, config, merge=merge)
 
             # Find output branches, without resolving dependency.
             self.parse_drop_keep_rename(config, dumped_tree, subdirective)
-            self.parse_calculation(config, dumped_tree, subdirective)
+            self.parse_calculation(config, subdirective)
 
             # Figure out the loading sequence of all variables, resolving
             # dependency issues.
-            known_names = [v.name for v in subdirective['input_branches']]
-            subdirective['known_names'] += known_names
+            subdirective['known_names'] += [
+                v.name for v in subdirective['input_branches']]
             vars_to_load = subdirective['output_branches'] + \
                 subdirective['temp_variables']
 
@@ -71,10 +74,12 @@ class BabyConfigParser(object):
             # Remove variables that can't be resolved
             for var in vars_to_load:
                 if var in subdirective['output_branches']:
-                    print("Output branch {} cannot be resolved, deleting...".format(var.name))
+                    print("{}Output branch {} cannot be resolved, deleting...{}".format(
+                        TC.YELLOW, var.name, TC.END))
                     subdirective['output_branches'].remove(var)
                 else:
-                    print("Temp variable {} cannot be resolved, deleting...".format(var.name))
+                    print("{}Temp variable {} cannot be resolved, deleting...{}".format(
+                        TC.YELLOW, var.name, TC.END))
                     subdirective['temp_variables'].remove(var)
 
             self.parse_selection(config, dumped_tree, subdirective)
@@ -125,13 +130,18 @@ class BabyConfigParser(object):
             directive['output_branches'].append(
                 Variable(datatype, br_out, br_in))
 
-    def parse_calculation(self, config, dumped_tree, directive):
+    def parse_calculation(self, config, directive):
         """
         Parse ``calculation`` section.
         """
         if 'calculation' in config:
             for name, code in config['calculation'].items():
-                datatype, rvalue = code.split(';')
+                try:
+                    datatype, rvalue = code.split(';')
+                except ValueError:
+                    raise ValueError('Illegal specification for {}: {}.'.format(
+                        name, code
+                    ))
 
                 if '^' in datatype:
                     datatype = datatype.strip('^')
@@ -154,9 +164,10 @@ class BabyConfigParser(object):
                 if resolved:
                     selection.append(expr)
                 else:
-                    print('Selection {} not resolved, deleting...'.format(expr))
+                    print('{}Selection {} not resolved, deleting...{}'.format(
+                        TC.YELLOW, expr, TC.END))
 
-            directive['selection'] = config['selection']
+            directive['selection'] = selection
 
     def load_missing_vars(self, expr, dumped_tree, directive):
         """
@@ -174,7 +185,7 @@ class BabyConfigParser(object):
                     directive['known_names'].append(v)
 
                 except Exception:
-                    print('WARNING: {} is not a known branch name.'.format(v))
+                    print('{} is not a known branch name.'.format(v))
                     resolved = False
 
         return resolved
@@ -242,21 +253,6 @@ class BabyConfigParser(object):
         except KeyError:
             raise KeyError('Branch {} not found.'.format(name))
 
-    @staticmethod
-    def update_config(config, update, merge=True):
-        """
-        Update ``config`` directory keys from the ``update`` directory, if the
-        same key is not present in ``config``.
-
-        Else merge the value from two keys if ``merge`` key argument is set to
-        ``True``.
-        """
-        for key, value in update.items():
-            if key not in config:
-                config[key] = value
-            elif merge:
-                config[key] += value
-
 
 #############
 # BabyMaker #
@@ -276,7 +272,7 @@ class BabyMaker(BaseMaker):
         self.template_filename = template_filename
         self.use_reformater = use_reformater
 
-    def gen(self, filename, **kwargs):
+    def gen(self, filename):
         parsed_config = self.read(self.config_filename)
         dumped_ntuple = self.dump(self.ntuple_filename)
         directive = self.directive_gen(parsed_config, dumped_ntuple)
