@@ -2,7 +2,7 @@
 #
 # Author: Yipeng Sun <syp at umd dot edu>
 # License: BSD 2-clause
-# Last Change: Thu Sep 10, 2020 at 03:32 AM +0800
+# Last Change: Tue Sep 22, 2020 at 02:22 AM +0800
 
 import pytest
 import os
@@ -211,13 +211,8 @@ def test_BabyConfigParser_parse_calculation(subdirective,
             'Y_P_shift': 'double;Y_P_TEMP',
         }
     }
-    dumped_tree = {
-        'Y_PX': 'float',
-        'Y_PY': 'float',
-        'Y_PZ': 'float',
-    }
     default_BabyConfigParser.parse_calculation(
-        config, dumped_tree, subdirective)
+        config, subdirective)
 
     assert subdirective['input_branches'] == []  # Dependency is resolved later
     assert subdirective['output_branches'] == [
@@ -324,28 +319,6 @@ def test_BabyConfigParser_load_var_not_exist(default_BabyConfigParser):
         default_BabyConfigParser.load_var('Z_PX', dumped_tree)
 
 
-def test_BabyConfigParser_update_config(default_BabyConfigParser):
-    config = {'a': 1, 'b': 2, 'e': [1, 2]}
-    update = {'a': 2, 'c': 3, 'e': [3]}
-    default_BabyConfigParser.update_config(config, update)
-
-    assert config['a'] == 3
-    assert config['b'] == 2
-    assert config['c'] == 3
-    assert config['e'] == [1, 2, 3]
-
-
-def test_BabyConfigParser_update_config_no_merge(default_BabyConfigParser):
-    config = {'a': 1, 'b': 2, 'e': [1, 2]}
-    update = {'a': 2, 'c': 3, 'e': [3]}
-    default_BabyConfigParser.update_config(config, update, merge=False)
-
-    assert config['a'] == 1
-    assert config['b'] == 2
-    assert config['c'] == 3
-    assert config['e'] == [1, 2]
-
-
 def test_BabyConfigParser_var_load_seq_normal(default_BabyConfigParser):
     known_names = ['a', 'b']
     vars_to_load = [
